From 8165f99731a0058abd72c2c7914ba318cea79281 Mon Sep 17 00:00:00 2001
From: Matt Whitlock <c-lightning@mattwhitlock.name>
Date: Sat, 23 Nov 2024 03:57:50 -0500
Subject: [PATCH] lightningd/test/Makefile: add missing dependency on
 header_versions_gen.h

lightningd/test/run-find_my_abspath.c includes ../lightningd.c, which includes
header_versions_gen.h, a generated header file.

lightningd/Makefile correctly declares that lightningd/lightningd.o depends on
header_versions_gen.h, but lightningd/test/Makefile lacks any such declaration
regarding lightningd/test/run-find_my_abspath.c, which leads to build failure:

In file included from lightningd/test/run-find_my_abspath.c:5:
lightningd/test/../lightningd.c:64:10: fatal error: header_versions_gen.h: No such file or directory
   64 | #include <header_versions_gen.h>
      |          ^~~~~~~~~~~~~~~~~~~~~~~

Declare the missing dependency in lightningd/test/Makefile so that Make will
ensure that header_versions_gen.h is generated before it attempts to build
lightningd/test/run-find_my_abspath.o.

Changelog-None
---
 lightningd/test/Makefile | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/lightningd/test/Makefile b/lightningd/test/Makefile
index 690ac37b89bedc4217f176483c3212df81a4c592..a9aa3c12852bb52ed8f17a4ec70748e0b73df7e5 100644
--- a/lightningd/test/Makefile
+++ b/lightningd/test/Makefile
@@ -7,6 +7,9 @@ LIGHTNINGD_TEST_PROGRAMS := $(LIGHTNINGD_TEST_OBJS:.o=)
 ALL_C_SOURCES += $(LIGHTNINGD_TEST_SRC)
 ALL_TEST_PROGRAMS += $(LIGHTNINGD_TEST_PROGRAMS)
 
+# run-find_my_abspath.c includes lightningd.c, which includes header_versions_gen.h
+lightningd/test/run-find_my_abspath.o: header_versions_gen.h
+
 LIGHTNINGD_TEST_COMMON_OBJS :=			\
 	common/amount.o				\
 	common/autodata.o			\
